/*
 *                      ..::PictoGame::..
 *
 * Copyright (C) Federico Vera 2010-2011 <dktcoding [at] gmail>
 *
 * PictoGame is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or any later
 * version.
 *
 * PictoGame is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received generateList copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package picto.app.gui;

import java.awt.Font;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTextPane;
import javax.swing.JTree;
import javax.swing.WindowConstants;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import picto.app.interfaces.Localizable;
import picto.utils.Text;

import static picto.utils.Text._;

/**
 *
 * @author Fido <dktcoding [at] gmail>
 */
public class HelpWindow extends JFrame implements Localizable, TreeSelectionListener{
    private static final long serialVersionUID = 34569874903975803L;

    /** Creates new form HelpWindow */
    public HelpWindow() {
        initComponents();
        generateList();
        updateTexts();
        addWeakReference();
        setSize(600, 300);
        setDefaultCloseOperation(DISPOSE_ON_CLOSE);
        editorPane.setContentType("text/html");
        jSplitPane1.setDividerLocation(250);
    }

    @Override
    public final void updateTexts() {
        setTitle(_("Help"));
        indexTree.revalidate();
        indexTree.updateUI();
        if (ev != null){
            valueChanged(ev);
        }
    }
    
    private void generateList(){
        DefaultMutableTreeNode treeNode1 = new DefaultMutableTreeNode(new Help("Help", null));
        DefaultMutableTreeNode treeNode2 = new DefaultMutableTreeNode(new Help("Introduction", "INTRO"));
        treeNode1.add(treeNode2);
        treeNode2 = new DefaultMutableTreeNode(new Help("Menus", null));
        DefaultMutableTreeNode treeNode3 = new DefaultMutableTreeNode(new Help("Game", null));
        DefaultMutableTreeNode treeNode4 = new DefaultMutableTreeNode(new Help("Open random phrase", "OPEN_RAND_PHRASE"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Open random pattern", "OPEN_RAND_GAME"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Open pattern", "OPEN_PATTERN"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Open...", "OPEN_MI"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Save...", "SAVE_MI"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Quit", "QUIT_MI"));
        treeNode3.add(treeNode4);
        treeNode2.add(treeNode3);
        treeNode3 = new DefaultMutableTreeNode(new Help("Edit", null));
        treeNode4 = new DefaultMutableTreeNode(new Help("Locale", "LOCALE_MI"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Enable dragging", "ENABLE_DRAGGING"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Enable mouse tracking", "ENABLE_MOUSE_TR"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Colors", "COLORS_MI"));
        treeNode3.add(treeNode4);
        treeNode2.add(treeNode3);
        treeNode3 = new DefaultMutableTreeNode(new Help("Pattern", null));
        treeNode4 = new DefaultMutableTreeNode(new Help("Clear board", "CLEAR_BOARD"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Check board", "CHECK_BOARD"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Custom phrase", "CUSTOM_PHRASE"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("New pattern", "NEW_PATTERN"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Show preview", "SHOW_PREVIEW"));
        treeNode3.add(treeNode4);
        treeNode4 = new DefaultMutableTreeNode(new Help("Attempt to solve", "ATTEMPT_TO_SOLVE"));
        treeNode3.add(treeNode4);
        treeNode2.add(treeNode3);
        treeNode3 = new DefaultMutableTreeNode(new Help("Extras...", "Have you ever played Contra?"));
        treeNode2.add(treeNode3);
        treeNode1.add(treeNode2);
        treeNode2 = new DefaultMutableTreeNode(new Help("Actions", null));
        treeNode1.add(treeNode2);
        treeNode2.add(new DefaultMutableTreeNode(new Help("Left click", "LEFT_CLICK_ACTION")));
        treeNode2.add(new DefaultMutableTreeNode(new Help("Right click", "RIGHT_CLICK_ACTION")));
        treeNode2 = new DefaultMutableTreeNode(new Help("F.A.Q.", null));
        treeNode1.add(treeNode2);
        treeNode2.add(new DefaultMutableTreeNode(new Help("QUESTION_1", "ANSWER_1")));
        treeNode2.add(new DefaultMutableTreeNode(new Help("QUESTION_2", "ANSWER_2")));
        treeNode2.add(new DefaultMutableTreeNode(new Help("QUESTION_3", "ANSWER_3")));
        treeNode2.add(new DefaultMutableTreeNode(new Help("QUESTION_4", "ANSWER_4")));
        treeNode2.add(new DefaultMutableTreeNode(new Help("QUESTION_5", "ANSWER_5")));
        indexTree.setModel(new DefaultTreeModel(treeNode1));
        indexTree.setRootVisible(false);
        indexTree.addTreeSelectionListener(this);
    }

    private TreeSelectionEvent ev;
    @Override public void valueChanged(TreeSelectionEvent e) {
        ev = e;
        DefaultMutableTreeNode node = (DefaultMutableTreeNode)
                                    indexTree.getLastSelectedPathComponent();
        if (node == null || !node.isLeaf()){return;}
        String foo = "<html><b>"
                   + getTitle(e.getNewLeadSelectionPath().toString())
                   + "</b><br><br><br>"
                   + ((Help)node.getUserObject()).getContent().replace("\\n", "<br>")
                   + "</html>";
        editorPane.setText(foo);
        editorPane.setCaretPosition(0);
    }

    private String getTitle(String path){
        path = path.toUpperCase();
        path = path.replace(", ", " -> ");
        return path;
    }
    
    private class Help{
        private String title;
        private String content;

        Help(String t, String c){
            title = t;
            content = c;
        }

        public String getContent(){
            return _(content);
        }

        @Override public String toString(){
            return _(title);
        }
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jSplitPane1 = new JSplitPane();
        jScrollPane1 = new JScrollPane();
        indexTree = new JTree();
        jScrollPane2 = new JScrollPane();
        editorPane = new JTextPane();

        setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);

        jSplitPane1.setDividerLocation(90);
        DefaultMutableTreeNode treeNode1 = new DefaultMutableTreeNode("root");
        indexTree.setModel(new DefaultTreeModel(treeNode1));
        indexTree.setRootVisible(false);
        jScrollPane1.setViewportView(indexTree);

        jSplitPane1.setLeftComponent(jScrollPane1);

        jScrollPane2.setDoubleBuffered(true);

        editorPane.setEditable(false);
        editorPane.setFont(new Font("DejaVu Sans Mono", 0, 13));
        jScrollPane2.setViewportView(editorPane);

        jSplitPane1.setRightComponent(jScrollPane2);

        GroupLayout layout = new GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(Alignment.LEADING)
            .addComponent(jSplitPane1, GroupLayout.DEFAULT_SIZE, 487, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(Alignment.LEADING)
            .addComponent(jSplitPane1, GroupLayout.DEFAULT_SIZE, 225, Short.MAX_VALUE)
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents
    @Override
    public final void addWeakReference() {
        Text.addWeakReference(this);
    }
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private JTextPane editorPane;
    private JTree indexTree;
    private JScrollPane jScrollPane1;
    private JScrollPane jScrollPane2;
    private JSplitPane jSplitPane1;
    // End of variables declaration//GEN-END:variables

}
