/*
 *                      ..::PictoGame::..
 *
 * Copyright (C) Federico Vera 2010-2011 <dktcoding [at] gmail>
 *
 * PictoGame is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or any later
 * version.
 *
 * PictoGame is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package picto.utils;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JSpinner;
import javax.swing.JTextField;
import javax.swing.LayoutStyle.ComponentPlacement;
import javax.swing.SpinnerNumberModel;
import javax.swing.SwingConstants;
import picto.app.interfaces.Localizable;

import static picto.utils.Text._;

/**
 *
 * @author Fido <dktcoding [at] gmail>
 */
public class PatternDataSetter extends JDialog implements Localizable, ActionListener{
    private static final long serialVersionUID = 673849098765346891L;
    private static PatternDataSetter instance;
    private static Picto pic = null;

    public static PatternDataSetter getInstance(){
        if (instance == null){
            instance = new PatternDataSetter();
        }
        return instance;
    }

    /** Creates new form PatternDataSetter */
    private PatternDataSetter() {
        initComponents();
        updateTexts();
        addWeakReference();
        setModal(true);
    }

    @Override
    public final void updateTexts() {
        setTitle(_("Pattern info"));
        titleLabel.setText(_("Name:"));
        authorLabel.setText(_("Author:"));
        dateLabel.setText(_("Date:"));
        rowsLabel.setText(_("Rows:"));
        columnsLabel.setText(_("Columns:"));
        createButton.setText(_("Create"));
        cancelButton.setText(_("Cancel"));
    }

    @Override
    public final void addWeakReference() {
        Text.addWeakReference(this);
    }

    private void resetToDefaults(){
        titleTextField.setText("");
        authorTextField.setText("");
        dateTextField.setText("");
        rowsSpinner.setValue(5);
        columnsSpinner.setValue(5);
    }

    public Picto showMessage(){
        resetToDefaults();
        setVisible(true);
        return pic;
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        titleTextField = new JTextField();
        authorTextField = new JTextField();
        dateTextField = new JTextField();
        titleLabel = new JLabel();
        authorLabel = new JLabel();
        dateLabel = new JLabel();
        columnsSpinner = new JSpinner();
        columnsLabel = new JLabel();
        rowsSpinner = new JSpinner();
        rowsLabel = new JLabel();
        cancelButton = new JButton();
        createButton = new JButton();

        titleLabel.setHorizontalAlignment(SwingConstants.TRAILING);
        titleLabel.setText("jLabel1");

        authorLabel.setHorizontalAlignment(SwingConstants.TRAILING);
        authorLabel.setText("jLabel2");

        dateLabel.setHorizontalAlignment(SwingConstants.TRAILING);
        dateLabel.setText("jLabel3");

        columnsSpinner.setModel(new SpinnerNumberModel(5, 5, 64, 1));

        columnsLabel.setText("Columns:");

        rowsSpinner.setModel(new SpinnerNumberModel(5, 5, 64, 1));

        rowsLabel.setText("Rows");

        cancelButton.setText("jButton1");
        cancelButton.addActionListener(this);

        createButton.setText("jButton2");
        createButton.addActionListener(this);

        GroupLayout layout = new GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(Alignment.LEADING)
                    .addGroup(Alignment.TRAILING, layout.createSequentialGroup()
                        .addComponent(rowsLabel)
                        .addPreferredGap(ComponentPlacement.RELATED)
                        .addComponent(rowsSpinner, GroupLayout.PREFERRED_SIZE, 93, GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(ComponentPlacement.RELATED)
                        .addComponent(columnsLabel)
                        .addPreferredGap(ComponentPlacement.RELATED)
                        .addComponent(columnsSpinner, GroupLayout.PREFERRED_SIZE, 94, GroupLayout.PREFERRED_SIZE))
                    .addGroup(Alignment.TRAILING, layout.createSequentialGroup()
                        .addGroup(layout.createParallelGroup(Alignment.LEADING, false)
                            .addComponent(dateLabel, Alignment.TRAILING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .addComponent(authorLabel, Alignment.TRAILING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                            .addComponent(titleLabel, Alignment.TRAILING, GroupLayout.DEFAULT_SIZE, 109, Short.MAX_VALUE))
                        .addPreferredGap(ComponentPlacement.RELATED)
                        .addGroup(layout.createParallelGroup(Alignment.TRAILING)
                            .addComponent(dateTextField, GroupLayout.DEFAULT_SIZE, 205, Short.MAX_VALUE)
                            .addComponent(authorTextField, GroupLayout.DEFAULT_SIZE, 205, Short.MAX_VALUE)
                            .addComponent(titleTextField, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, 205, Short.MAX_VALUE)))
                    .addGroup(Alignment.TRAILING, layout.createSequentialGroup()
                        .addComponent(createButton)
                        .addPreferredGap(ComponentPlacement.RELATED)
                        .addComponent(cancelButton)))
                .addContainerGap())
        );

        layout.linkSize(SwingConstants.HORIZONTAL, new Component[] {columnsSpinner, rowsSpinner});

        layout.setVerticalGroup(
            layout.createParallelGroup(Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(Alignment.BASELINE)
                    .addComponent(titleTextField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
                    .addComponent(titleLabel))
                .addPreferredGap(ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(Alignment.BASELINE)
                    .addComponent(authorTextField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
                    .addComponent(authorLabel))
                .addPreferredGap(ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(Alignment.BASELINE)
                    .addComponent(dateTextField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
                    .addComponent(dateLabel))
                .addPreferredGap(ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(Alignment.BASELINE)
                    .addComponent(columnsSpinner, GroupLayout.PREFERRED_SIZE, 28, GroupLayout.PREFERRED_SIZE)
                    .addComponent(columnsLabel)
                    .addComponent(rowsSpinner, GroupLayout.PREFERRED_SIZE, 28, GroupLayout.PREFERRED_SIZE)
                    .addComponent(rowsLabel))
                .addPreferredGap(ComponentPlacement.RELATED, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(layout.createParallelGroup(Alignment.BASELINE)
                    .addComponent(cancelButton)
                    .addComponent(createButton))
                .addContainerGap())
        );

        pack();
    }

    // Code for dispatching events from components to event handlers.

    public void actionPerformed(java.awt.event.ActionEvent evt) {
        if (evt.getSource() == cancelButton) {
            PatternDataSetter.this.cancelButtonActionPerformed(evt);
        }
        else if (evt.getSource() == createButton) {
            PatternDataSetter.this.createButtonActionPerformed(evt);
        }
    }// </editor-fold>//GEN-END:initComponents

    private void cancelButtonActionPerformed(ActionEvent evt) {//GEN-FIRST:event_cancelButtonActionPerformed
        resetToDefaults();
        setVisible(false);
        pic = null;
    }//GEN-LAST:event_cancelButtonActionPerformed

    private void createButtonActionPerformed(ActionEvent evt) {//GEN-FIRST:event_createButtonActionPerformed
        pic = new Picto((Integer)rowsSpinner.getValue()
                      , (Integer)columnsSpinner.getValue());
        pic.setTitle(titleTextField.getText());
        pic.setAuthor(authorTextField.getText());
        pic.setDate(dateTextField.getText());
        setVisible(false);
    }//GEN-LAST:event_createButtonActionPerformed
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private JLabel authorLabel;
    private JTextField authorTextField;
    private JButton cancelButton;
    private JLabel columnsLabel;
    private JSpinner columnsSpinner;
    private JButton createButton;
    private JLabel dateLabel;
    private JTextField dateTextField;
    private JLabel rowsLabel;
    private JSpinner rowsSpinner;
    private JLabel titleLabel;
    private JTextField titleTextField;
    // End of variables declaration//GEN-END:variables

}
